==> afmtools_0.1.0.tar.gz: afmtools/man/per.arfima.Rd <==
\name{per.arfima}
\alias{per.arfima}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Periodogram by Fast Fourier Transform
}
\description{
Computes the periodogram of a signal \code{z} by the Fast Fourier Transform (FFT).
}
\usage{
per.arfima(z)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{z}{
univariate signal / time series z
}
}
\value{
	\item{freq}{
Fourier frequencies \code{omega_j = 2*pi*j/n}, where \code{n} is the length of \code{z}, and \code{j=1,...,[n/2]}
}
	\item{spec}{
corresponding value of the periodogram \code{I(omega_j)}
}
}
\references{
Brockwell, P. and Davis, R. (1991). \emph{Time Series: Theory and Methods}. Springer. New York.
}
\author{
Wilfredo Palma, Georg M. Goerg
}
\seealso{
\code{\link{spectrum.arfima}}, \code{\link{spectrum}}
}
\examples{
data(MammothCreek)
y=MammothCreek-mean(MammothCreek)
x=per.arfima(y)
cbind(x$spec,x$freq)
plot(x$freq,x$spec,type="l",xlab="frequencies",ylab="spectrum", main="Periodogram")

#### For a ARMA model:
sim <- arima.sim(n=1000, list(ar = c(0.556), ma = c(-0.634)), sd = 1.5)
x=per.arfima(sim)
plot(x$freq,x$spec,type="l",xlab="frequencies",ylab="spectrum", main="Periodogram")

#### For USAccDeaths database
data(USAccDeaths)
x=per.arfima(USAccDeaths)
plot(x$freq,x$spec,type="l",xlab="frequencies",ylab="spectrum", main="Periodogram")

USAstand=(USAccDeaths-mean(USAccDeaths))/sqrt(var(USAccDeaths))
z=per.arfima(USAstand)
plot(z$freq,z$spec,type="l",xlab="frequencies",ylab="spectrum", main="Periodogram")
}
\keyword{arfima}
\keyword{likelihood}% __ONLY ONE__ keyword per line

==> afmtools_0.1.2.tar.gz: afmtools/man/per.arfima.Rd <==
\name{per.arfima}
\alias{per.arfima}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Periodogram by Fast Fourier Transform
}
\description{
Computes the periodogram of a signal \code{z} by the Fast Fourier Transform (FFT).
}
\usage{
per.arfima(z)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{z}{
univariate signal / time series z
}
}
\value{
	\item{freq}{
Fourier frequencies \eqn{\omega_j=2\pi j/n}, where \eqn{n} is the length of \eqn{z}, and \eqn{j=1,...,[n/2]}
}
	\item{spec}{
corresponding value of the periodogram \eqn{I(\omega_j)}
}
}
\references{
Brockwell, P. and Davis, R. (1991). \emph{Time Series: Theory and Methods}. Springer. New York.
}
\author{
Wilfredo Palma, Georg M. Goerg
}
\seealso{
\code{\link{spectrum.arfima}}, \code{\link{spectrum}}
}
\examples{
data(MammothCreek)
y=MammothCreek-mean(MammothCreek)
x=per.arfima(y)
cbind(x$spec,x$freq)
plot(x$freq,x$spec,type="l",xlab="frequencies",ylab="spectrum", 
main="Periodogram")

#### For a ARMA model:
sim <- arima.sim(n=1000, list(ar = c(0.556), ma = c(-0.634)), sd = 1.5)
x=per.arfima(sim)
plot(x$freq,x$spec,type="l",xlab="frequencies",ylab="spectrum", 
main="Periodogram")

#### For USAccDeaths database
data(USAccDeaths)
x=per.arfima(USAccDeaths)
plot(x$freq,x$spec,type="l",xlab="frequencies",ylab="spectrum", 
main="Periodogram")

USAstand=(USAccDeaths-mean(USAccDeaths))/sqrt(var(USAccDeaths))
z=per.arfima(USAstand)
plot(z$freq,z$spec,type="l",xlab="frequencies",ylab="spectrum", 
main="Periodogram")
}
\keyword{loglikelihood}
